/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */
AUI.add('liferay-search-sort-util', function () {
  var SortUtil = {
    addURLParameter: function addURLParameter(key, value, parameterArray) {
      key = encodeURIComponent(key);
      value = encodeURIComponent(value);
      parameterArray[parameterArray.length] = [key, value].join('=');
      return parameterArray;
    },
    removeURLParameters: function removeURLParameters(key, parameterArray) {
      key = encodeURIComponent(key);
      var newParameters = parameterArray.filter(function (item) {
        var itemSplit = item.split('=');

        if (itemSplit && itemSplit[0] === key) {
          return false;
        }

        return true;
      });
      return newParameters;
    },
    setURLParameters: function setURLParameters(key, values, parameterArray) {
      var newParameters = SortUtil.removeURLParameters(key, parameterArray);
      values.forEach(function (item) {
        newParameters = SortUtil.addURLParameter(key, item, newParameters);
      });
      return newParameters;
    },
    updateQueryString: function updateQueryString(key, selections, queryString) {
      var search = queryString;
      var hasQuestionMark = false;

      if (search[0] === '?') {
        hasQuestionMark = true;
      }

      if (hasQuestionMark) {
        search = search.substr(1);
      }

      var parameterArray = search.split('&').filter(function (item) {
        return item.trim() !== '';
      });
      var newParameters = SortUtil.setURLParameters(key, selections, parameterArray);
      search = newParameters.join('&');

      if (hasQuestionMark) {
        search = '?' + search;
      }

      return search;
    }
  };
  Liferay.namespace('Search').SortUtil = SortUtil;
}, '', {
  requires: []
});
//# sourceMappingURL=sort_util.js.map